import { Application } from "express";
import { Container } from "inversify";
import { ApiApp, ApiRequest, ApiResponse, AppConfig } from "ts-lambda-api";
/**
 * Simple console application that hosts an express HTTP
 * server.
 *
 * A request is mapped from the HTTP request to the ApiServer
 * event format, a ApiServer instance then processes the request.
 * The ApiServer response is mapped to a standard HTTP response and
 * returned to the express client.
 */
export declare class ApiConsoleApp extends ApiApp {
    private static readonly MAX_REQUEST_BODY_SIZE;
    private static readonly HTTP_METHODS_WITH_ENTITY;
    private static readonly APP_OPTIONS;
    protected readonly expressApp: Application;
    private server?;
    /**
     * Builds an new console app.
     *
     * If a value for`appConfig` is not passed, the `serverLogger`
     * property is missing or the `serverLogger.logTimestamp` property
     * is missing timestamps will be enabled for logger output.
     */
    constructor(controllersPath: string[], appConfig?: AppConfig, appContainer?: Container);
    run(request: ApiRequest, context: any): Promise<ApiResponse>;
    /**
     * Starts the express server.
     *
     * @param args Command line arguments for this server, see --help for more info.
     */
    runServer(args: string[]): Promise<void>;
    private configureServer;
    private configureSwaggerUi;
    stopServer(): Promise<void>;
    private parseArguments;
    private handleHttpRequest;
    private mapRequestToApiEvent;
    private forwardApiResponse;
}
